@@ -40,12 +40,22 @@ mf_export <- function(x,
   mar <- .gmapsf$args$mar
   bgmap <- .gmapsf$args$bg
 
-  if (is(x, "Raster")) {
-    bb <- st_bbox(x)
-    xd <- diff(bb[c(1, 3)]) * 0.04
-    yd <- diff(bb[c(2, 4)]) * 0.04
-    nbb <- bb + c(xd, yd, -xd, -yd)
-    x <- st_as_sfc(st_bbox(nbb), crs = st_crs(x))
+  if (is(x, "SpatRaster")) {
+    if (!requireNamespace("terra", quietly = TRUE)) {
+      stop(
+        "'terra' package is needed for this function to work. Please install it.",
+        call. = FALSE
+      )
+    }
+    proj <- terra::crs(x)
+    bb <- terra::ext(x)[c(1, 3, 2, 4)]
+    y <- st_as_sfc(st_bbox(bb))
+    st_crs(y) <- proj
+    mf_export(
+      x = y, export = export, filename = filename, width = width, height = height, res = res,
+      expandBB = c(rep(-.04, 4)) + expandBB, theme = theme, ...
+    )
+    return(invisible(x))
   }
 
   # transform to bbox
@@ -95,7 +105,7 @@ mf_export <- function(x,
         x = bb,
         width = width,
         height = height,
-        mar = mar, res = res, format = "svg"
+        mar = mar, res = 96, format = "svg"
       ) / 96
     }
     svg(filename = filename, width = fd[1], height = fd[2], ...)
